#region Copyright Syncfusion Inc. 2001 - 2005
//
//  Copyright Syncfusion Inc. 2001 - 2005. All rights reserved.
//
//  Use of this code is subject to the terms of our license.
//  A copy of the current license can be obtained at any time by e-mailing
//  licensing@syncfusion.com. Any infringement will be prosecuted under
//  applicable laws. 
//
#endregion

using System;
using System.Drawing;
using System.Collections;
using System.ComponentModel;
using System.Windows.Forms;
using System.Data;

using Syncfusion.Grouping;
using Syncfusion.Windows.Forms.Grid;
using Syncfusion.Windows.Forms.Grid.Grouping;

namespace ForeignKeyReference
{
	/// <summary>
	/// Summary description for Form1.
	/// </summary>
	public class Form1 : System.Windows.Forms.Form
	{
		private Syncfusion.Windows.Forms.Grid.Grouping.GridGroupingControl gridGroupingControl1;
		/// <summary>
		/// Required designer variable.
		/// </summary>
		private System.ComponentModel.Container components = null;

		public Form1()
		{
			//
			// Required for Windows Form Designer support
			//
			InitializeComponent();

			USStatesCollection usStates = USStatesCollection.CreateDefaultCollection();
			CountriesCollection countries = CountriesCollection.CreateDefaultCollection();

			this.gridGroupingControl1.Engine.SourceListSet.Add("Countries", countries);
			this.gridGroupingControl1.Engine.SourceListSet.Add("USStates", usStates);

            this.gridGroupingControl1.TableControlCurrentCellShowingDropDown += new GridTableControlCurrentCellShowingDropDownEventHandler(gridGroupingControl1_TableControlCurrentCellShowingDropDown);

			DataTable table = new DataTable();
			table.Columns.Add("Id", typeof(string));
			table.Columns.Add("Country", typeof(string));
			table.Columns.Add("State", typeof(string));

			// and then add a few rows:
			for ( int i=0; i < 50; i++ )
			{
				table.Rows.Add(table.NewRow());
				table.Rows[i][0] = i;
				table.Rows[i][1] = countries[i%8].CountryCode;
				table.Rows[i][2] = usStates[i%8].Key;
			}

			GridTableDescriptor mainTd = this.gridGroupingControl1.TableDescriptor;
			//mainTd.TableOptions.AllowForeignKeyDropDown = false;

			GridRelationDescriptor usStatesRd = new GridRelationDescriptor();
			usStatesRd.Name = "State";
			usStatesRd.RelationKind = RelationKind.ForeignKeyReference;
			usStatesRd.ChildTableName = "USStates";  // SourceListSet name for lookup
			usStatesRd.RelationKeys.Add("State", "Key");
			usStatesRd.ChildTableDescriptor.Appearance.AlternateRecordFieldCell.BackColor = Color.Beige;
			usStatesRd.ChildTableDescriptor.VisibleColumns.Add("Name");
			usStatesRd.ChildTableDescriptor.SortedColumns.Add("Name");
			usStatesRd.ChildTableDescriptor.AllowEdit = false;
			usStatesRd.ChildTableDescriptor.AllowNew = false;  // Make pencil icon disappear, users can't modify states.
			mainTd.Relations.Add(usStatesRd);

			GridRelationDescriptor countriesRd = new GridRelationDescriptor();
			//countriesRd.Name = "Country";  - default will be ChildTableName = "Countries"
			countriesRd.RelationKind = RelationKind.ForeignKeyReference;
			countriesRd.ChildTableName = "Countries";  // SourceListSet name for lookup
			countriesRd.RelationKeys.Add("Country", "CountryCode");
			countriesRd.ChildTableDescriptor.Appearance.AlternateRecordFieldCell.BackColor = Color.Beige;
			countriesRd.ChildTableDescriptor.AllowEdit = true;
			countriesRd.ChildTableDescriptor.AllowNew = true;  // Make pencil icon appear, allow user to add countries (these setting will be overriden by CountriesCollection.IsReadOnly / CountriesCollection.IsFixedSize properties if they are true).
			mainTd.Relations.Add(countriesRd);

//			mainTd.Columns.Add("Id");
//			mainTd.Columns.Add(new GridColumnDescriptor("Country", "Countries_CountryCode", "Country"));
//			mainTd.Columns.Add(new GridColumnDescriptor("CountryName", "Countries_Name"));   // countriesRd.Name.FieldName  (see countriesRd.Name)
//			mainTd.Columns.Add(new GridColumnDescriptor("US State", "State_Name"));  // usStatesRd.Name.FieldName 
////
////
////			mainTd.Columns["Country"].Width = 50;  // Width will be determined based on width of column in related table ...
////			mainTd.Columns["Countries_Name"].Width = 200;
//			//mainTd.Columns["Country_Name"].Width = 50; 
//			// Double-click on US State column to resize to default ...

			this.gridGroupingControl1.DataSource = table;
			mainTd.Name = "ForeignKeyReference";
            mainTd.Columns[1].Width = 120;
            mainTd.Columns[1].Width = 200;
			// After data source was set you could call LoadDefault and remove columns
			//			mainTd.Columns.LoadDefault();
			//			mainTd.Columns.Remove("Country_CountryCode");

			//foreach (Record r in this.gridGroupingControl1.GetTable("Country").PrimaryKeySortedRecords)
			//	Console.WriteLine(r.Info);
			this.Load += new EventHandler(Form1_Load);
		}

        string[] filters = new string[] { "A*", "B*", "C*", "D*" };
        int filter = 0;

        private void gridGroupingControl1_TableControlCurrentCellShowingDropDown(object sender, GridTableControlCurrentCellShowingDropDownEventArgs e)
        {
            GridCurrentCell cc = e.TableControl.CurrentCell;
            GridTableCellStyleInfo style = (GridTableCellStyleInfo) e.TableControl.Model[cc.RowIndex, cc.ColIndex];
            Console.WriteLine(style.TableCellIdentity.Column.Name);
            GridDropDownGridListControlCellRenderer cr = (GridDropDownGridListControlCellRenderer) cc.Renderer;
            GridListControl glc = cr.ListControlPart;
            ((GridDropDownGridListControlPart) glc).DropDownRows = 5;

            GridGroupTypedListRecordsCollection dt = (GridGroupTypedListRecordsCollection) glc.DataSource;

            ((CurrencyManager) glc.BindingContext[dt]).Position = 0;
            Record r = null;
            if (glc.SelectedIndex >= 0 && glc.SelectedIndex <= dt.Count)
                r = (Record) dt[glc.SelectedIndex];

            dt.TableDescriptor.RecordFilters.Clear();
            
                FilterCondition fc = new FilterCondition(FilterCompareOperator.Like, filters[filter++ % 4]);
                RecordFilterDescriptor rfd = new RecordFilterDescriptor("Name", FilterLogicalOperator.Or, new Syncfusion.Grouping.FilterCondition[] { fc });
                dt.TableDescriptor.RecordFilters.Add(rfd);

            int index = dt.IndexOf(r);
            if (index != -1)
                glc.SelectedIndex = index;
            else
                glc.SelectedIndex = 0;


            //dt.TableDescriptor.RecordFilters[0].Conditions[0].CompareText = "B*";
        }
		/// <summary>
		/// Clean up any resources being used.
		/// </summary>
		protected override void Dispose( bool disposing )
		{
			if( disposing )
			{
				if (components != null) 
				{
					components.Dispose();
				}
			}
			base.Dispose( disposing );
		}

		#region Windows Form Designer generated code
		/// <summary>
		/// Required method for Designer support - do not modify
		/// the contents of this method with the code editor.
		/// </summary>
		private void InitializeComponent()
		{
			this.gridGroupingControl1 = new Syncfusion.Windows.Forms.Grid.Grouping.GridGroupingControl();
			((System.ComponentModel.ISupportInitialize)(this.gridGroupingControl1)).BeginInit();
			this.SuspendLayout();
			// 
			// gridGroupingControl1
			// 
			this.gridGroupingControl1.Anchor = ((System.Windows.Forms.AnchorStyles)((((System.Windows.Forms.AnchorStyles.Top | System.Windows.Forms.AnchorStyles.Bottom) 
				| System.Windows.Forms.AnchorStyles.Left) 
				| System.Windows.Forms.AnchorStyles.Right)));
			this.gridGroupingControl1.BackColor = System.Drawing.SystemColors.Window;
			this.gridGroupingControl1.IntelliMousePanning = true;
			this.gridGroupingControl1.Location = new System.Drawing.Point(32, 24);
			this.gridGroupingControl1.Name = "gridGroupingControl1";
			this.gridGroupingControl1.Size = new System.Drawing.Size(584, 344);
			this.gridGroupingControl1.TabIndex = 0;
			this.gridGroupingControl1.TableDescriptor.Name = "Default";
			this.gridGroupingControl1.Text = "gridGroupingControl1";
			// 
			// Form1
			// 
			this.AutoScaleBaseSize = new System.Drawing.Size(5, 13);
			this.ClientSize = new System.Drawing.Size(648, 422);
			this.Controls.Add(this.gridGroupingControl1);
			this.Name = "Form1";
			this.Text = "Form1";
			((System.ComponentModel.ISupportInitialize)(this.gridGroupingControl1)).EndInit();
			this.ResumeLayout(false);

		}
		#endregion

		/// <summary>
		/// The main entry point for the application.
		/// </summary>
		[STAThread]
		static void Main() 
		{
			Application.Run(new Form1());
		}

		private void Form1_Load(object sender, EventArgs e)
		{
			Console.WriteLine("Form1_load");
		}
	}
}
